pub struct UnitSectionOffset<T = usize>(pub T);Expand description
An offset into the .debug_info or .debug_types sections.
This type does not store which section the offset applies to. You will need to either
determine that from the context of its use, or store a SectionId along with it.
Tuple Fields
0: TImplementations
Sourceimpl<T: ReaderOffset> UnitSectionOffset<T>
impl<T: ReaderOffset> UnitSectionOffset<T>
Sourcepub fn to_unit_offset<R>(&self, unit: &UnitHeader<R>) -> Option<UnitOffset<T>>where
R: Reader<Offset = T>,
pub fn to_unit_offset<R>(&self, unit: &UnitHeader<R>) -> Option<UnitOffset<T>>where
R: Reader<Offset = T>,
Convert an offset to be relative to the start of the given unit, instead of relative to the start of the section.
Returns None if the offset is not in bounds for the unit’s entries.
Sourcepub fn to_debug_info_offset<R>(
&self,
unit: &UnitHeader<R>,
) -> Option<DebugInfoOffset<T>>where
R: Reader<Offset = T>,
pub fn to_debug_info_offset<R>(
&self,
unit: &UnitHeader<R>,
) -> Option<DebugInfoOffset<T>>where
R: Reader<Offset = T>,
Convert an offset to be relative to the start of the .debug_info section,
instead of relative to the start of the section for the given unit.
Returns None if the unit is not within the .debug_info section.
Sourcepub fn to_debug_types_offset<R>(
&self,
unit: &UnitHeader<R>,
) -> Option<DebugTypesOffset<T>>where
R: Reader<Offset = T>,
pub fn to_debug_types_offset<R>(
&self,
unit: &UnitHeader<R>,
) -> Option<DebugTypesOffset<T>>where
R: Reader<Offset = T>,
Convert an offset to be relative to the start of the .debug_types section,
instead of relative to the start of the section for the given unit.
Returns None if the unit is not within the .debug_types section.